/*
Copyright The Kubegene Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1alpha1 "kubegene.io/kubegene/pkg/apis/gene/v1alpha1"
	scheme "kubegene.io/kubegene/pkg/client/clientset/versioned/scheme"
)

// ExecutionsGetter has a method to return a ExecutionInterface.
// A group's client should implement this interface.
type ExecutionsGetter interface {
	Executions(namespace string) ExecutionInterface
}

// ExecutionInterface has methods to work with Execution resources.
type ExecutionInterface interface {
	Create(*v1alpha1.Execution) (*v1alpha1.Execution, error)
	Update(*v1alpha1.Execution) (*v1alpha1.Execution, error)
	UpdateStatus(*v1alpha1.Execution) (*v1alpha1.Execution, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.Execution, error)
	List(opts v1.ListOptions) (*v1alpha1.ExecutionList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Execution, err error)
	ExecutionExpansion
}

// executions implements ExecutionInterface
type executions struct {
	client rest.Interface
	ns     string
}

// newExecutions returns a Executions
func newExecutions(c *ExecutionV1alpha1Client, namespace string) *executions {
	return &executions{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the execution, and returns the corresponding execution object, and an error if there is any.
func (c *executions) Get(name string, options v1.GetOptions) (result *v1alpha1.Execution, err error) {
	result = &v1alpha1.Execution{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("executions").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Executions that match those selectors.
func (c *executions) List(opts v1.ListOptions) (result *v1alpha1.ExecutionList, err error) {
	result = &v1alpha1.ExecutionList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("executions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested executions.
func (c *executions) Watch(opts v1.ListOptions) (watch.Interface, error) {
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("executions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Watch()
}

// Create takes the representation of a execution and creates it.  Returns the server's representation of the execution, and an error, if there is any.
func (c *executions) Create(execution *v1alpha1.Execution) (result *v1alpha1.Execution, err error) {
	result = &v1alpha1.Execution{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("executions").
		Body(execution).
		Do().
		Into(result)
	return
}

// Update takes the representation of a execution and updates it. Returns the server's representation of the execution, and an error, if there is any.
func (c *executions) Update(execution *v1alpha1.Execution) (result *v1alpha1.Execution, err error) {
	result = &v1alpha1.Execution{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("executions").
		Name(execution.Name).
		Body(execution).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *executions) UpdateStatus(execution *v1alpha1.Execution) (result *v1alpha1.Execution, err error) {
	result = &v1alpha1.Execution{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("executions").
		Name(execution.Name).
		SubResource("status").
		Body(execution).
		Do().
		Into(result)
	return
}

// Delete takes name of the execution and deletes it. Returns an error if one occurs.
func (c *executions) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("executions").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *executions) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("executions").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched execution.
func (c *executions) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Execution, err error) {
	result = &v1alpha1.Execution{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("executions").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
